@@ -1,5 +1,5 @@
-# $Revision: 2.6 $
-# $Id: ISBN.pm,v 2.6 2007/08/15 08:06:49 comdog Exp $
+# $Revision: 2.16 $
+# $Id: ISBN.pm,v 2.16 2008/08/09 04:29:55 comdog Exp $
 package Business::ISBN;
 use strict;
 
@@ -12,24 +12,26 @@ Business::ISBN - work with International Standard Book Numbers
 	use Business::ISBN;
 
 	# 10 digit ISBNs
-	$isbn_object = Business::ISBN->new('1565922573');
-	$isbn_object = Business::ISBN->new('1-56592-257-3');
+	$isbn10 = Business::ISBN->new('1565922573');
+	$isbn10 = Business::ISBN->new('1-56592-257-3');
 
 	# 13 digit ISBNs
-	$isbn_object = Business::ISBN->new('978-0-596-52724-2');
+	$isbn13 = Business::ISBN->new('978-0-596-52724-2');
 
 	# convert
-	$isbn10 = $isbn->as_isbn10;    # for the 978 prefixes
+	$isbn10 = $isbn13->as_isbn10;    # for the 978 prefixes
 	
 	$isbn13 = $isbn10->as_isbn13;
 
-
+	# maybe you don't care what it is as long as everything works
+	$isbn = Business::ISBN->new( $ARGV[0] );
+	
 	#print the ISBN with hyphens at usual positions 
-	print $isbn_object->as_string;
+	print $isbn->as_string;
 
 	#print the ISBN with hyphens at specified positions.
 	#this not does affect the default positions
-	print $isbn_object->as_string([]);
+	print $isbn->as_string([]);
 
 	#print the group code or publisher code
 	print $isbn->group_code;
@@ -37,14 +39,14 @@ Business::ISBN - work with International Standard Book Numbers
 	print $isbn->publisher_code;
 
 	#check to see if the ISBN is valid
-	$isbn_object->is_valid;
+	$isbn->is_valid;
 
 	#fix the ISBN checksum.  BEWARE:  the error might not be
 	#in the checksum!
-	$isbn_object->fix_checksum;
+	$isbn->fix_checksum;
 
 	# create an EAN13 barcode in PNG format
-	$isbn_object->png_barcode;
+	$isbn->png_barcode;
 
 =head1 DESCRIPTION
 
@@ -68,9 +70,9 @@ use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS $debug %group_data
 	$MAX_GROUP_CODE_LENGTH %ERROR_TEXT );
 
 use Carp qw(carp croak cluck);
-use Exporter qw( import );
+use base qw(Exporter);
 
-use Business::ISBN::Data 1.09; # now a separate module
+use Business::ISBN::Data 20081020; # now a separate module
 # ugh, hack
 *group_data = *Business::ISBN::country_data;
 sub _group_data { $group_data{ $_[1] } }
@@ -99,14 +101,16 @@ BEGIN {
 		INVALID_GROUP_CODE INVALID_PUBLISHER_CODE
 		BAD_CHECKSUM GOOD_ISBN BAD_ISBN 
 		INVALID_PREFIX
-		%ERROR_TEXT);
+		%ERROR_TEXT
+		valid_isbn_checksum
+		);
 
 	%EXPORT_TAGS = ( 
 		'all' => \@EXPORT_OK,	
 		);
 	};
 	
-$VERSION = "2.02";
+$VERSION = "2.04";
 
 sub INVALID_PREFIX         () { -4 };
 sub INVALID_GROUP_CODE     () { -2 };
@@ -128,6 +132,40 @@ sub BAD_ISBN               () {  0 };
 use Business::ISBN10;
 use Business::ISBN13;
 
+=head2 Function interface
+
+=over 4
+
+=item valid_isbn_checksum( ISBN10 | ISBN13 )
+
+This function is exportable on demand, and works for either 10
+or 13 character ISBNs).
+
+	use Business::ISBN qw( valid_isbn_checksum );
+	
+Returns 1 if the ISBN is a valid ISBN with the right checksum.
+
+Returns 0 if the ISBN has valid prefix and publisher codes, but an
+invalid checksum.
+
+Returns undef if the ISBN does not validate for any other reason.
+
+=back 
+
+=cut
+
+sub valid_isbn_checksum
+	{
+	my $isbn = shift;
+	
+	my $obj =  Business::ISBN->new( $isbn );
+	
+	return 1 if $obj->is_valid_checksum == GOOD_ISBN;
+	return 0 if $obj->is_valid_checksum == BAD_CHECKSUM;
+	return;
+	}
+	
+=head2 Object interface
 
 =over 4
 
@@ -173,7 +211,7 @@ extremely useful.  One should check the validity of the ISBN
 with C<is_valid()> rather than relying on the return value
 of the constructor.  If all one wants to do is check the
 validity of an ISBN, one can skip the object-oriented
-interface and use the C<is_valid_checksum()> function
+interface and use the C<valid_isbn_checksum()> function
 which is exportable on demand.
 
 If the constructor decides it cannot create an object, it
@@ -417,7 +455,7 @@ assumes that you know what you are doing and will attempt
 to use the least three positions specified.  If you pass
 an anonymous array of several positions, the list will
 be sorted and the lowest three positions will be used.
-Positions less than 1 and greater than 9 are silently
+Positions less than 1 and greater than 12 are silently
 ignored.
 
 A terminating 'x' is changed to 'X'.
@@ -541,7 +579,7 @@ sub png_barcode
 		}
 
 	my $image = GD::Barcode::EAN13->new($ean)->plot->png;
-
+	
 	return $image;
 	}
 	
